"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AppLog_1 = require("./AppLog");
const BuildLog_1 = require("./BuildLog");
const Logger_1 = require("../../Logger");
/**
 * Contains info about app and build logs for a given Connection.
 */
class LogManager {
    constructor(connection) {
        this.connection = connection;
        // Maps projectIDs to AppLog instances
        this.appLogMap = new Map();
        this.buildLogMap = new Map();
    }
    getOrCreateAppLog(projectID, projectName) {
        let appLog = this.appLogMap.get(projectID);
        if (appLog == null) {
            Logger_1.default.i("Creating app log for " + projectName);
            // we have to create it
            appLog = new AppLog_1.default(projectID, projectName);
            this.appLogMap.set(projectID, appLog);
        }
        return appLog;
    }
    getAppLog(projectID) {
        return this.appLogMap.get(projectID);
    }
    getOrCreateBuildLog(projectID, projectName) {
        let buildLog = this.buildLogMap.get(projectID);
        if (buildLog == null) {
            Logger_1.default.i("Creating build log for " + projectName);
            // we have to create it
            buildLog = new BuildLog_1.default(this.connection, projectID, projectName);
            this.buildLogMap.set(projectID, buildLog);
        }
        return buildLog;
    }
    /**
     * When a connection dies, we have to stop updating its logs, but we should keep the logs visible.
     */
    onConnectionDisconnect() {
        this.appLogMap.forEach((log) => {
            log.stopUpdating();
        });
        this.buildLogMap.forEach((log) => {
            log.stopUpdating();
        });
    }
    /**
     * When a connection is reset, we have to wipe all the logs since the old logs are no longer valid.
     * The easiest way to is destroy them and start from scratch.
     */
    onConnectionReconnect() {
        this.appLogMap.forEach((log) => {
            log.destroy();
            this.getOrCreateAppLog(log.projectID, log.projectName);
        });
        this.buildLogMap.forEach((log) => {
            log.destroy();
            this.getOrCreateBuildLog(log.projectID, log.projectName);
        });
    }
}
exports.default = LogManager;
//# sourceMappingURL=MicroclimateLogManager.js.map